@@ -27,6 +27,7 @@ from .utils import resolve_local_commit_info
 from .helpers import intersect_dict
 from .models import (
     MqlQueryResultSeries,
+    MqlQueryResultSource,
     MqlQueryStatus,
     MqlQueryStatusResp,
     QueryResult,
@@ -370,13 +371,13 @@ class BackendInterface(BaseInterface):  # noqa: D
         )
         return MQLServerImage.from_gql_dict(self.execute(query)["latestMqlServer"])
 
-    def get_metrics_metadata(self) -> List[Dict[str, Any]]:  # type: ignore[misc]
+    def get_metrics_metadata(self, model_key_id: Optional[int] = None) -> List[Dict[str, Any]]:  # type: ignore[misc]
         """Fetch all org metrics' metadata."""
         query = gql(
             """
-            query MetricsMetadataQuery ($pageSize: Int!){
+            query MetricsMetadataQuery ($pageSize: Int!, $modelId: Int){
                 myOrganization {
-                    metrics (pageSize: $pageSize){
+                    metrics (pageSize: $pageSize, modelId: $modelId){
                         name
                         description
                         displayName
@@ -403,15 +404,17 @@ class BackendInterface(BaseInterface):  # noqa: D
             }
             """
         )
-        return self.execute(query, variable_values={"pageSize": MAX_PAGE_SIZE})["myOrganization"]["metrics"]
+        return self.execute(query, variable_values={"pageSize": MAX_PAGE_SIZE, "modelId": model_key_id},)[
+            "myOrganization"
+        ]["metrics"]
 
-    def get_metric_metadata_by_name(self, metric_name: str) -> Dict[str, Any]:  # type: ignore[misc]
+    def get_metric_metadata_by_name(self, metric_name: str, model_key_id: Optional[int] = None) -> Dict[str, Any]:  # type: ignore[misc]
         """Fetch a single org metric metadata."""
         query = gql(
             """
-            query MetricMetadataQuery ($metricName: String!) {
+            query MetricMetadataQuery ($metricName: String!, $modelId: Int) {
                 myOrganization {
-                    metric (name: $metricName){
+                    metric (name: $metricName, modelId: $modelId){
                         name
                         description
                         displayName
@@ -440,7 +443,9 @@ class BackendInterface(BaseInterface):  # noqa: D
             }
             """
         )
-        return self.execute(query, variable_values={"metricName": metric_name})["myOrganization"]["metric"]
+        return self.execute(query, variable_values={"metricName": metric_name, "modelId": model_key_id},)[
+            "myOrganization"
+        ]["metric"]
 
 
 class MQLInterface(BaseInterface):  # noqa: D
@@ -757,8 +762,8 @@ class MQLInterface(BaseInterface):  # noqa: D
 
     def get_dimensions(
         self,
-        model_key: Optional[ModelKey] = None,
         metric_names: Optional[List[str]] = None,
+        model_key: Optional[ModelKey] = None,
     ) -> List[Dimension]:
         """Get a list of all unique Dimension objects."""
         variable_values: Dict[str, Any] = {  # type: ignore[misc]
@@ -1058,8 +1063,12 @@ class MQLInterface(BaseInterface):  # noqa: D
             error=q["error"] if q["error"] else None,
             sql=q["sql"],
             result=result,
-            result_source=q["resultSource"],
-            result_primary_time_granularity=q["resultPrimaryTimeGranularity"],
+            result_source=(None if q["resultSource"] is None else MqlQueryResultSource(q["resultSource"])),
+            result_primary_time_granularity=(
+                None
+                if q["resultPrimaryTimeGranularity"] is None
+                else TimeGranularity(q["resultPrimaryTimeGranularity"].lower())
+            ),
             chart_value_min=q["chartValueMin"],
             chart_value_max=q["chartValueMax"],
         )
